@@ -411,10 +411,13 @@ class Model:
             for variable in self.variables:
                 if variable.row > sizetable[0]:
                     variable.row = variable.row + sizetable[1]
-            for style in self.styles:        
-                if style.row > sizetable[0]:
+            for style in self.styles:
+                if style.row == sizetable[0]:
+                    for n in range(sizetable[1]):
+                        self.__styles.append(Style(style.name,style.row+n,style.column,style.value))
+                elif style.row > sizetable[0]:
                     style.row = style.row + sizetable[1]
-                    style.rename()
+                style.rename()
         return None
 
     def import_data(self, data):
@@ -426,13 +429,14 @@ class Model:
             if variable.name in data:
                 variable.value = data[variable.name]
             elif 'table' in data:
-                print()
-#                for tbl in data['table']:
-#                    n = 0
-#                    for variable2 in self.variables:
-#                        if variable.name
-#                    if variable.name in data['table']:
-
+                n = -1
+                for table in data['table']:
+                    n = n + 1
+                    if variable.name in table:
+                        if n == 0:
+                            variable.value = table[variable.name]
+                        else:
+                            self.__variables.append(Variable(variable.name,varible.row+n,variable.column,table[variable.name]))
         return None
 
     def past_in_worksheet(self,worksheet):
